@@ -1,10 +1,11 @@
 import argparse
-import glob
 import json
 import os
 import socket
 import threading
 
+from pathlib import Path
+
 SERVER_ADDRESS = "/tmp/py3status_uds"
 MAX_SIZE = 1024
 
@@ -158,7 +159,7 @@ class CommandRunner:
                         found_modules.add(module_name)
 
         if self.debug:
-            self.py3_wrapper.log("found %s" % found_modules)
+            self.py3_wrapper.log(f"found {found_modules}")
         return found_modules
 
     def refresh(self, data):
@@ -171,7 +172,7 @@ class CommandRunner:
         for module_name in self.find_modules(modules):
             module = self.py3_wrapper.output_modules[module_name]
             if self.debug:
-                self.py3_wrapper.log("refresh %s" % module)
+                self.py3_wrapper.log(f"refresh {module}")
             if module["type"] == "py3status":
                 module["module"].force_update()
             else:
@@ -208,7 +209,7 @@ class CommandRunner:
         """
         command = data.get("command")
         if self.debug:
-            self.py3_wrapper.log("Running remote command %s" % command)
+            self.py3_wrapper.log(f"Running remote command {command}")
         if command == "refresh":
             self.refresh(data)
         elif command == "refresh_all":
@@ -230,22 +231,22 @@ class CommandServer(threading.Thread):
         self.py3_wrapper = py3_wrapper
 
         self.command_runner = CommandRunner(py3_wrapper)
-        server_address = "{}.{}".format(SERVER_ADDRESS, os.getpid())
+        server_address = Path(f"{SERVER_ADDRESS}.{os.getpid()}")
         self.server_address = server_address
 
         # Make sure the socket does not already exist
         try:
-            os.unlink(server_address)
+            server_address.unlink()
         except OSError:
-            if os.path.exists(server_address):
+            if server_address.exists():
                 raise
 
         # Create a UDS socket
         sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
-        sock.bind(server_address)
+        sock.bind(server_address.as_posix())
 
         if self.debug:
-            self.py3_wrapper.log("Unix domain socket at %s" % server_address)
+            self.py3_wrapper.log(f"Unix domain socket at {server_address}")
 
         # Listen for incoming connections
         sock.listen(1)
@@ -256,9 +257,9 @@ class CommandServer(threading.Thread):
         Remove the socket as it is no longer needed.
         """
         try:
-            os.unlink(self.server_address)
+            self.server_address.unlink()
         except OSError:
-            if os.path.exists(self.server_address):
+            if self.server_address.exists():
                 raise
 
     def run(self):
@@ -282,7 +283,7 @@ class CommandServer(threading.Thread):
                     if data:
                         data = json.loads(data.decode("utf-8"))
                         if self.debug:
-                            self.py3_wrapper.log(u"received %s" % data)
+                            self.py3_wrapper.log(f"received {data}")
                         self.command_runner.run_command(data)
                 finally:
                     # Clean up the connection
@@ -302,25 +303,21 @@ def command_parser():
     class Parser(argparse.ArgumentParser):
         # print usages and exit on errors
         def error(self, message):
-            print("\x1b[1;31merror: \x1b[0m{}".format(message))
+            print(f"\x1b[1;31merror: \x1b[0m{message}")
             self.print_help()
             self.exit(1)
 
         # hide choices on errors
         def _check_value(self, action, value):
             if action.choices is not None and value not in action.choices:
-                raise argparse.ArgumentError(
-                    action, "invalid choice: '{}'".format(value)
-                )
+                raise argparse.ArgumentError(action, f"invalid choice: '{value}'")
 
     # make parser
     parser = Parser(formatter_class=argparse.RawTextHelpFormatter)
 
     # parser: add verbose, version
     for short, name, msg in INFORMATION:
-        short = "-%s" % short
-        arg = "--%s" % name
-        parser.add_argument(short, arg, action="store_true", help=msg)
+        parser.add_argument(f"-{short}", f"--{name}", action="store_true", help=msg)
 
     # make subparsers // ALIAS_DEPRECATION: remove metavar later
     metavar = "{click,list,refresh}"
@@ -352,7 +349,7 @@ def command_parser():
     # click subparser: add button, index, width, height, relative_{x,y}, x, y
     sp = sps["click"]
     for name, msg in CLICK_OPTIONS:
-        arg = "--{}".format(name)
+        arg = f"--{name}"
         if name == "button":
             sp.add_argument(arg, metavar="INT", type=int, help=msg, default=1)
         elif name == "index":
@@ -365,21 +362,21 @@ def command_parser():
     # docstring subparser: add check, diff, update
     sp = sps["docstring"]
     for name, msg in DOCSTRING_OPTIONS:
-        arg = "--{}".format(name)
+        arg = f"--{name}"
         sp.add_argument(arg, action="store_true", help=msg)
 
     # refresh subparser: add all
     sp = sps["refresh"]
     for name, msg in REFRESH_OPTIONS:
-        arg = "--{}".format(name)
+        arg = f"--{name}"
         sp.add_argument(arg, action="store_true", help=msg)
 
     # list subparser: add all, core, user, full
     sp = sps["list"]
     for short, name, msg in LIST_OPTIONS:
-        name = "--{}".format(name)
+        name = f"--{name}"
         if short:
-            short = "-{}".format(short)
+            short = f"-{short}"
             sp.add_argument(short, name, action="store_true", help=msg)
         else:
             sp.add_argument(name, action="store_true", help=msg)
@@ -424,7 +421,7 @@ def command_parser():
         from platform import python_version
         from py3status.version import version
 
-        print("py3status {} (python {})".format(version, python_version()))
+        print(f"py3status {version} (python {python_version()})")
         parser.exit()
     elif not options.command:
         parser.error("too few arguments")
@@ -462,24 +459,25 @@ def parse_list_or_docstring(options, sps):
     import py3status.docstrings as docstrings
 
     # HARDCODE: make include path to search for user modules
-    home_path = os.path.expanduser("~")
-    xdg_home_path = os.environ.get("XDG_CONFIG_HOME", "{}/.config".format(home_path))
+    home_path = Path.home()
+    xdg_home_path = Path(
+        os.environ.get("XDG_CONFIG_HOME", home_path / ".config")
+    ).resolve()
     options.include_paths = [
-        "{}/py3status/modules".format(xdg_home_path),
-        "{}/i3status/py3status".format(xdg_home_path),
-        "{}/i3/py3status".format(xdg_home_path),
-        "{}/.i3/py3status".format(home_path),
+        xdg_home_path / "py3status/modules",
+        xdg_home_path / "i3status/py3status",
+        xdg_home_path / "i3/py3status",
+        home_path / ".i3/py3status",
     ]
     include_paths = []
     for path in options.include_paths:
-        path = os.path.abspath(path)
-        if os.path.isdir(path) and os.listdir(path):
+        if path.is_dir() and any(path.iterdir()):
             include_paths.append(path)
     options.include_paths = include_paths
 
     # init
     config = vars(options)
-    modules = [x.rsplit(".py", 1)[0] for x in config["module"]]
+    modules = [Path(x).stem for x in config["module"]]
 
     # list module names and details
     if config["command"] == "list":
@@ -527,25 +525,25 @@ def send_command():
     options = command_parser()
     msg = json.dumps(vars(options)).encode("utf-8")
     if len(msg) > MAX_SIZE:
-        verbose("Message length too long, max length (%s)" % MAX_SIZE)
+        verbose(f"Message length too long, max length ({MAX_SIZE})")
 
     # find all likely socket addresses
-    uds_list = glob.glob("{}.[0-9]*".format(SERVER_ADDRESS))
+    uds_list = Path(SERVER_ADDRESS).parent.glob(f"{Path(SERVER_ADDRESS).name}.[0-9]*")
 
-    verbose('message "%s"' % msg)
+    verbose(f"message {msg!r}")
     for uds in uds_list:
         # Create a UDS socket
         sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
 
         # Connect the socket to the port where the server is listening
-        verbose("connecting to %s" % uds)
+        verbose(f"connecting to {uds}")
         try:
-            sock.connect(uds)
-        except socket.error:
+            sock.connect(uds.as_posix())
+        except OSError:
             # this is a stale socket so delete it
             verbose("stale socket deleting")
             try:
-                os.unlink(uds)
+                uds.unlink()
             except OSError:
                 pass
             continue
