@@ -1,9 +1,9 @@
-# -*- coding: utf-8 -*-
 import ast
 import re
-import os.path
 import difflib
 
+from pathlib import Path
+
 from py3status.helpers import print_stderr
 
 
@@ -11,7 +11,7 @@ def modules_directory():
     """
     Get the core modules directory.
     """
-    return os.path.join(os.path.dirname(os.path.abspath(__file__)), "modules")
+    return Path(__file__).resolve().parent / "modules"
 
 
 def parse_readme():
@@ -20,10 +20,10 @@ def parse_readme():
     returns a dict of {<module_name>: <documentation>}
     """
     name = None
-    re_mod = re.compile(r'^\#\#\# <a name="(?P<name>[a-z_0-9]+)"></a>')
-    readme_file = os.path.join(modules_directory(), "README.md")
+    re_mod = re.compile(r'^### <a name="(?P<name>[a-z_0-9]+)"></a>')
+    readme_file = modules_directory() / "README.md"
     modules_dict = {}
-    with open(readme_file) as f:
+    with readme_file.open() as f:
         for row in f.readlines():
             match = re_mod.match(row)
             if match:
@@ -48,23 +48,21 @@ def core_module_docstrings(
     paths = {}
     docstrings = {}
     if include_core:
-        for file in os.listdir(modules_directory()):
-            if file.endswith(".py"):
-                name = file[:-3]
-                if name != "__init__":
-                    paths[name] = (os.path.join(modules_directory(), file), "core")
+        for file in modules_directory().iterdir():
+            if file.suffix == ".py":
+                if file.stem != "__init__":
+                    paths[file.stem] = (file, "core")
 
     if include_user:
         # include user modules
         for include_path in sorted(config["include_paths"]):
-            for file in sorted(os.listdir(include_path)):
-                if not file.endswith(".py"):
+            for file in sorted(include_path.iterdir()):
+                if file.suffix != ".py":
                     continue
-                name = file[:-3]
-                paths[name] = (os.path.join(include_path, file), "user")
+                paths[file.stem] = (file, "user")
     for name in paths:
         path, module_type = paths[name]
-        with open(path) as f:
+        with path.open() as f:
             try:
                 module = ast.parse(f.read())
             except SyntaxError:
@@ -101,15 +99,15 @@ def create_readme(data):
     """
     out = ['<a name="top"></a>Modules\n========\n\n']
     # Links
-    for module in sorted(data.keys()):
-        desc = "".join(data[module]).strip().split("\n")[0]
+    for module, lines in sorted(data.items()):
+        desc = "".join(lines).strip().split("\n")[0]
         format_str = "\n**[{name}](#{name})** — {desc}\n"
         out.append(format_str.format(name=module, desc=desc))
     # details
-    for module in sorted(data.keys()):
+    for module, lines in sorted(data.items()):
         out.append(
             '\n---\n\n### <a name="{name}"></a>{name}\n\n{details}\n'.format(
-                name=module, details="".join(data[module]).strip()
+                name=module, details="".join(lines).strip()
             )
         )
     return "".join(out)
@@ -176,7 +174,7 @@ def _to_docstring(doc):
     """
 
     def format_fn(line, status):
-        """ format function """
+        """format function"""
         # swap &lt; &gt; to < >
         line = re_to_tag.sub(r"<\1>", line)
         if re_to_data.match(line):
@@ -207,7 +205,7 @@ def _from_docstring_md(doc):
     """
 
     def format_fn(line, status):
-        """ format function """
+        """format function"""
 
         def fix_tags(line):
             # In markdown we need to escape < > and & for display
@@ -235,11 +233,11 @@ def _from_docstring_md(doc):
             # parameters
             if re_from_param.match(line):
                 m = re_from_param.match(line)
-                line = "  - `{}` {}".format(m.group(1), fix_tags(m.group(3)))
+                line = "\n- `{}` {}".format(m.group(1), fix_tags(m.group(3)))
             # status items
             elif re_from_status.match(line):
                 m = re_from_status.match(line)
-                line = "  - `{}` {}".format(m.group(1), fix_tags(m.group(3)))
+                line = "\n- `{}` {}".format(m.group(1), fix_tags(m.group(3)))
             # bullets
             elif re_from_item.match(line):
                 line = re_from_item.sub(r"  -", fix_tags(line))
@@ -260,7 +258,7 @@ def _from_docstring_rst(doc):
     """
 
     def format_fn(line, status):
-        """ format function """
+        """format function"""
 
         if re_from_data.match(line):
             line = re_from_data.sub(r"**\1** ", line)
@@ -298,17 +296,17 @@ def update_docstrings():
     files = {}
     # update modules
     for mod in modules_dict:
-        mod_file = os.path.join(modules_directory(), mod + ".py")
-        with open(mod_file) as f:
+        mod_file = modules_directory() / f"{mod}.py"
+        with mod_file.open() as f:
             files[mod] = f.readlines()
 
-    for mod in files:
+    for mod, rows in files.items():
         replaced = False
         done = False
         lines = False
         out = []
         quotes = None
-        for row in files[mod]:
+        for row in rows:
             # deal with single or double quoted docstring
             if not quotes:
                 if row.strip().startswith('"""'):
@@ -329,8 +327,8 @@ def update_docstrings():
                 continue
             if not lines or done:
                 out.append(row)
-        mod_file = os.path.join(modules_directory(), mod + ".py")
-        with open(mod_file, "w") as f:
+        mod_file = modules_directory() / f"{mod}.py"
+        with mod_file.open("w") as f:
             f.writelines(out)
     print_stderr("Modules updated from README.md")
 
@@ -344,17 +342,14 @@ def check_docstrings(show_diff=False, config=None, mods=None):
     modules_readme = core_module_docstrings(config=config)
     warned = False
     if create_readme(readme) != create_readme(modules_readme):
-        for module in sorted(readme):
+        for module, lines in sorted(readme.items()):
             if mods and module not in mods:
                 continue
             err = None
             if module not in modules_readme:
-                err = "Module {} in README but not in /modules".format(module)
-            elif (
-                "".join(readme[module]).strip()
-                != "".join(modules_readme[module]).strip()
-            ):
-                err = "Module {} docstring does not match README".format(module)
+                err = f"Module {module} in README but not in /modules"
+            elif "".join(lines).strip() != "".join(modules_readme[module]).strip():
+                err = f"Module {module} docstring does not match README"
             if err:
                 if not warned:
                     print_stderr("Documentation does not match!\n")
@@ -365,7 +360,7 @@ def check_docstrings(show_diff=False, config=None, mods=None):
             if mods and module not in mods:
                 continue
             if module not in readme:
-                print_stderr("Module {} in /modules but not in README".format(module))
+                print_stderr(f"Module {module} in /modules but not in README")
         if show_diff:
             print_stderr(
                 "\n".join(
@@ -387,18 +382,17 @@ def update_readme_for_modules(modules):
     readme = parse_readme()
     module_docstrings = core_module_docstrings()
     if modules == ["__all__"]:
-        modules = core_module_docstrings().keys()
+        modules = list(core_module_docstrings())
     for module in modules:
         if module in module_docstrings:
-            print_stderr("Updating README.md for module {}".format(module))
+            print_stderr(f"Updating README.md for module {module}")
             readme[module] = module_docstrings[module]
         else:
-            print_stderr("Module {} not in core modules".format(module))
+            print_stderr(f"Module {module} not in core modules")
 
     # write the file
-    readme_file = os.path.join(modules_directory(), "README.md")
-    with open(readme_file, "w") as f:
-        f.write(create_readme(readme))
+    readme_file = modules_directory() / "README.md"
+    readme_file.write_text(create_readme(readme))
 
 
 def show_modules(config, modules_list):
@@ -418,12 +412,12 @@ def show_modules(config, modules_list):
         from fnmatch import fnmatch
 
         for _filter in modules_list:
-            for name in modules.keys():
+            for name in modules:
                 if fnmatch(name, _filter):
                     if name not in new_modules:
                         new_modules.append(name)
     else:
-        new_modules = modules.keys()
+        new_modules = list(modules)
 
     for name in sorted(new_modules):
         module = _to_docstring(modules[name])
@@ -431,9 +425,9 @@ def show_modules(config, modules_list):
         if details:
             dash_len = len(name) + 4
             print("#" * dash_len)
-            print("# {} #".format(name))
+            print(f"# {name} #")
             print("#" * dash_len)
             for description in module:
                 print(description[:-1])
         else:
-            print("%-22s %s" % (name, desc))
+            print(f"{name:<22} {desc}")
