@@ -1,14 +1,14 @@
+import time
+
 from ast import literal_eval
 from sys import argv
 from threading import Event
-from time import sleep, time
 
 from py3status.core import Common, Module
 
 
 class MockPy3statusWrapper:
-    """
-    """
+    """ """
 
     class EventThread:
         def process_event(self, *arg, **kw):
@@ -53,6 +53,9 @@ class MockPy3statusWrapper:
     def timeout_queue_add(self, *arg, **kw):
         pass
 
+    def clear_timeout_due(self, *arg, **kw):
+        pass
+
     def log(self, *arg, **kw):
         print(arg[0])
 
@@ -96,8 +99,8 @@ def module_test(module_class, config=None):
 
     while not m.error_messages:
         try:
-            for meth in m.methods:
-                m.methods[meth]["cached_until"] = time()
+            for my_method in m.methods.values():
+                my_method["cached_until"] = time.monotonic()
             m.run()
             output = m.get_latest()
             for item in output:
@@ -124,7 +127,7 @@ def module_test(module_class, config=None):
                     output = output[0]
                 print(output)
 
-            sleep(1)
+            time.sleep(1)
         except KeyboardInterrupt:
             m.kill()
             break
