@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-"""
+r"""
 Display air quality polluting in a given location.
 
 An air quality index (AQI) is a number used by government agencies to communicate
@@ -30,12 +29,12 @@ Configuration parameters:
             (151, '#CC0033', 'Unhealthy'),
             (201, '#660099', 'Very Unhealthy'),
             (301, '#7E0023', 'Hazardous')])*
+    thresholds: specify color thresholds to use (default {'aqi': True})
 
-.. Note::
-
+Notes:
     Your station may have individual scores for pollutants not listed below.
     See https://api.waqi.info/feed/@UID/?token=TOKEN (Replace UID and TOKEN)
-    for an explicit list of valid placeholders to use, eg
+    for a full list of placeholders to use.
 
 Format placeholders:
     {aqi} air quality index
@@ -78,7 +77,7 @@ Color options:
     color_bad: print a color for error (if any) from the site
 
 Color thresholds:
-    aqi: print a color based on the value of aqi
+    xxx: print a color based on the value of `xxx` placeholder
 
 Examples:
 ```
@@ -115,77 +114,83 @@ from datetime import datetime
 
 
 class Py3status:
-    """
-    """
+    """ """
+
     # available configuration parameters
-    auth_token = 'demo'
+    auth_token = "demo"
     cache_timeout = 3600
-    format = '[\?color=aqi {city_name}: {aqi} {category}]'
+    format = r"[\?color=aqi {city_name}: {aqi} {category}]"
     format_datetime = {}
-    location = 'Shanghai'
+    location = "Shanghai"
     quality_thresholds = [
-        (0, '#009966', 'Good'),
-        (51, '#FFDE33', 'Moderate'),
-        (101, '#FF9933', 'Sensitively Unhealthy'),
-        (151, '#CC0033', 'Unhealthy'),
-        (201, '#660099', 'Very Unhealthy'),
-        (301, '#7E0023', 'Hazardous')
+        (0, "#009966", "Good"),
+        (51, "#FFDE33", "Moderate"),
+        (101, "#FF9933", "Sensitively Unhealthy"),
+        (151, "#CC0033", "Unhealthy"),
+        (201, "#660099", "Very Unhealthy"),
+        (301, "#7E0023", "Hazardous"),
     ]
+    thresholds = {"aqi": True}
 
     def post_config_hook(self):
-        self.auth_token = {'token': self.auth_token}
-        self.request_timeout = 10
-        self.url = 'https://api.waqi.info/feed/%s/' % self.location
+        self.auth_token = {"token": self.auth_token}
+        self.url = f"https://api.waqi.info/feed/{self.location}/"
         self.init_datetimes = []
         for word in self.format_datetime:
             if (self.py3.format_contains(self.format, word)) and (
-                    word in self.format_datetime):
+                word in self.format_datetime
+            ):
                 self.init_datetimes.append(word)
 
-        self.thresholds = []
-        for index_aqi, index_color, index_category in self.quality_thresholds:
-            self.thresholds.append((index_aqi, index_color))
+        if isinstance(self.thresholds, dict):
+            if self.thresholds.get("aqi") is True:
+                aqi = [(x[0], x[1]) for x in self.quality_thresholds]
+                self.thresholds["aqi"] = aqi
+
+        self.thresholds_init = self.py3.get_color_names_list(self.format)
 
     def _get_aqi_data(self):
         try:
-            return self.py3.request(
-                self.url, params=self.auth_token, timeout=self.request_timeout
-            ).json()
+            return self.py3.request(self.url, params=self.auth_token).json()
         except self.py3.RequestException:
             return None
 
     def _organize(self, data):
         new_data = {}
-        for k, v in self.py3.flatten_dict(data, delimiter='_').items():
-            new_data[''.join(k.replace('data_', '', 1).rsplit('_v', 1))] = v
+        for k, v in self.py3.flatten_dict(data, delimiter="_").items():
+            new_data["".join(k.replace("data_", "", 1).rsplit("_v", 1))] = v
         return new_data
 
     def _manipulate(self, data):
         for index_aqi, index_color, index_category in self.quality_thresholds:
-            if data['aqi'] >= index_aqi:
-                data['category'] = index_category
+            if data["aqi"] >= index_aqi:
+                data["category"] = index_category
 
-        if self.thresholds:
-            self.py3.threshold_get_color(data['aqi'], 'aqi')
+        for x in self.thresholds_init:
+            if x in data:
+                self.py3.threshold_get_color(data[x], x)
 
         for k in self.init_datetimes:
             if k in data:
-                data[k] = self.py3.safe_format(datetime.strftime(
-                    datetime.fromtimestamp(data[k]), self.format_datetime[k]))
+                data[k] = self.py3.safe_format(
+                    datetime.strftime(
+                        datetime.fromtimestamp(data[k]), self.format_datetime[k]
+                    )
+                )
         return data
 
     def air_quality(self):
         aqi_data = self._get_aqi_data()
         if aqi_data:
-            if aqi_data.get('status') == 'ok':
+            if aqi_data.get("status") == "ok":
                 aqi_data = self._organize(aqi_data)
                 aqi_data = self._manipulate(aqi_data)
-            elif aqi_data.get('status') == 'error':
-                self.py3.error(aqi_data.get('data'))
+            elif aqi_data.get("status") == "error":
+                self.py3.error(aqi_data.get("data"))
 
         return {
-            'cached_until': self.py3.time_in(self.cache_timeout),
-            'full_text': self.py3.safe_format(self.format, aqi_data),
+            "cached_until": self.py3.time_in(self.cache_timeout),
+            "full_text": self.py3.safe_format(self.format, aqi_data),
         }
 
 
@@ -194,4 +199,5 @@ if __name__ == "__main__":
     Run module in test mode.
     """
     from py3status.module_test import module_test
+
     module_test(Py3status)
