@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Display number of pending updates for Arch Linux.
 
@@ -17,7 +16,7 @@ Requires:
     auracle: a flexible command line client for arch linux's user repository
     trizen: lightweight pacman wrapper and AUR helper
     yay: yet another yogurt. pacman wrapper and aur helper written in go
-```
+    paru: feature packed AUR helper
 
 @author Iain Tatch <iain.tatch@gmail.com>
 @license BSD
@@ -33,8 +32,7 @@ STRING_NOT_INSTALLED = "{} not installed"
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     cache_timeout = 600
@@ -47,7 +45,9 @@ class Py3status:
     def post_config_hook(self):
         helper = {
             "pacman": self.py3.check_commands(["checkupdates"]),
-            "aur": self.py3.check_commands(["auracle", "trizen", "yay", "cower"]),
+            "aur": self.py3.check_commands(
+                ["auracle", "trizen", "yay", "cower", "paru"]
+            ),
         }
         if self.format:
             placeholders = self.py3.get_placeholders_list(self.format)
@@ -72,7 +72,7 @@ class Py3status:
 
         for key in helper:
             value = getattr(self, "_get_{}_updates".format(helper[key]), None)
-            setattr(self, "_get_{}_updates".format(key), value)
+            setattr(self, f"_get_{key}_updates", value)
 
     def _get_checkupdates_updates(self):
         try:
@@ -109,6 +109,13 @@ class Py3status:
         except self.py3.CommandError:
             return None
 
+    def _get_paru_updates(self):
+        try:
+            updates = self.py3.command_output(["paru", "-Qua"])
+            return len(updates.splitlines())
+        except self.py3.CommandError as ce:
+            return None if ce.error else 0
+
     def arch_updates(self):
         pacman, aur, total, full_text = None, None, None, ""
 
