@@ -55,12 +55,12 @@ SAMPLE OUTPUT
 {'full_text': 'all:  34.4% ( 82.0 KiB/s)'}
 """
 
-from time import time
+import time
+from pathlib import Path
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     cache_timeout = 10
@@ -91,7 +91,7 @@ class Py3status:
 
         if self.init["diskstats"]:
             self.last_diskstats = self._get_diskstats(self.disk)
-            self.last_time = time()
+            self.last_time = time.monotonic()
 
         self.thresholds_init = self.py3.get_color_names_list(self.format)
 
@@ -130,7 +130,7 @@ class Py3status:
         if disk and disk.startswith("/dev/"):
             disk = disk[5:]
 
-        with open("/proc/diskstats") as fd:
+        with Path("/proc/diskstats").open() as fd:
             for line in fd:
                 data = line.split()
                 if disk:
@@ -145,7 +145,7 @@ class Py3status:
         return read, write
 
     def _calc_diskstats(self, diskstats):
-        current_time = time()
+        current_time = time.monotonic()
         timedelta = current_time - self.last_time
         read = (diskstats[0] - self.last_diskstats[0]) / timedelta
         write = (diskstats[1] - self.last_diskstats[1]) / timedelta
