@@ -86,8 +86,7 @@ import urllib.parse as urlparse
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     auth_token = None
@@ -133,7 +132,7 @@ class Py3status:
             auth = None
         try:
             info = self.py3.request(url, auth=auth)
-        except (self.py3.RequestException):
+        except self.py3.RequestException:
             return
         if info and info.status_code == 200:
             return int(info.json()["total_count"])
@@ -162,7 +161,7 @@ class Py3status:
         url += "?per_page=100"
         try:
             info = self.py3.request(url, auth=(self.username, self.auth_token))
-        except (self.py3.RequestException):
+        except self.py3.RequestException:
             return
         if info.status_code == 200:
             links = info.headers.get("Link")
@@ -253,7 +252,7 @@ class Py3status:
                     # open repo page if there are no unread notifications
                     url = self.url_base + "/" + self.repo
             # open url in default browser
-            self.py3.command_run("xdg-open {}".format(url))
+            self.py3.command_run(f"xdg-open {url}")
             self.py3.prevent_refresh()
         elif button != self.button_refresh:
             # only refresh the module if needed
