@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Display upcoming Google Calendar events.
 
@@ -6,6 +5,9 @@ This module will display information about upcoming Google Calendar events
 in one of two formats which can be toggled with a button press. The event
 URL may also be opened in a web browser with a button press.
 
+Some events details can be retreived in the Google Calendar API Documentation.
+https://developers.google.com/calendar/v3/reference/events
+
 Configuration parameters:
     auth_token: The path to where the access/refresh token will be saved
         after successful credential authorization.
@@ -13,6 +15,8 @@ Configuration parameters:
     blacklist_events: Event names in this list will not be shown in the module
         (case insensitive).
         (default [])
+    browser_invocation: Command to run to open browser. Curly braces stands for URL opened.
+        (default "xdg-open {}")
     button_open: Opens the event URL in the default web browser.
         (default 3)
     button_refresh: Refreshes the module and updates the list of events.
@@ -29,31 +33,40 @@ Configuration parameters:
     force_lowercase: Sets whether to force all event output to lower case.
         (default False)
     format: The format for module output.
-        (default '{events}|\?color=event \u2687')
+        (default '{events}|\\?color=event \u2687')
     format_date: The format for date related format placeholders.
         May be any Python strftime directives for dates.
         (default '%a %d-%m')
     format_event: The format for each event. The information can be toggled
         with 'button_toggle' based on the value of 'is_toggled'.
-        *(default '[\?color=event {summary}][\?if=is_toggled  ({start_time}'
+        *(default '[\\?color=event {summary}][\\?if=is_toggled  ({start_time}'
         ' - {end_time}, {start_date})|[ ({location})][ {format_timer}]]')*
     format_notification: The format for event warning notifications.
         (default '{summary} {start_time} - {end_time}')
     format_separator: The string used to separate individual events.
-        (default ' \| ')
+        (default ' \\| ')
     format_time: The format for time-related placeholders except `{format_timer}`.
         May use any Python strftime directives for times.
         (default '%I:%M %p')
     format_timer: The format used for the {format_timer} placeholder to display
         time until an event starts or time until an event in progress is over.
-        *(default '\?color=time ([\?if=days {days}d ][\?if=hours {hours}h ]'
-        '[\?if=minutes {minutes}m])[\?if=is_current  left]')*
+        *(default '\\?color=time ([\\?if=days {days}d ][\\?if=hours {hours}h ]'
+        '[\\?if=minutes {minutes}m])[\\?if=is_current  left]')*
     ignore_all_day_events: Sets whether to display all day events or not.
         (default False)
     num_events: The maximum number of events to display.
         (default 3)
+    preferred_event_link: link to open in the browser.
+        accepted values :
+        hangoutLink (open the VC room associated with the event),
+        htmlLink (open the event's details in Google Calendar)
+        fallback to htmlLink if the preferred_event_link does not exist it the event.
+        (default "htmlLink")
     response: Only display events for which the response status is
-        on the list. (default ['accepted'])
+        on the list.
+        Available values in the Google Calendar API's documentation,
+        look for the attendees[].responseStatus.
+        (default ['accepted'])
     thresholds: Thresholds for events. The first entry is the color for event 1,
         the second for event 2, and so on.
         (default [])
@@ -69,6 +82,7 @@ Configuration parameters:
     warn_timeout: The number of seconds before a warning should be issued again.
         (default 300)
 
+
 Control placeholders:
     {is_toggled} a boolean toggled by button_toggle
 
@@ -137,10 +151,14 @@ SAMPLE OUTPUT
 """
 
 import httplib2
-import os
 import datetime
+import time
+from pathlib import Path
 
-from apiclient import discovery
+try:
+    from googleapiclient import discovery
+except ImportError:
+    from apiclient import discovery
 from oauth2client import client
 from oauth2client import clientsecrets
 from oauth2client import tools
@@ -154,12 +172,12 @@ APPLICATION_NAME = "py3status google_calendar module"
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     auth_token = "~/.config/py3status/google_calendar.auth_token"
     blacklist_events = []
+    browser_invocation = "xdg-open {}"
     button_open = 3
     button_refresh = 2
     button_toggle = 1
@@ -167,21 +185,22 @@ class Py3status:
     client_secret = "~/.config/py3status/google_calendar.client_secret"
     events_within_hours = 12
     force_lowercase = False
-    format = "{events}|\?color=event \u2687"
+    format = "{events}|\\?color=event \u2687"
     format_date = "%a %d-%m"
     format_event = (
-        "[\?color=event {summary}][\?if=is_toggled  ({start_time}"
+        r"[\?color=event {summary}][\?if=is_toggled  ({start_time}"
         " - {end_time}, {start_date})|[ ({location})][ {format_timer}]]"
     )
     format_notification = "{summary} {start_time} - {end_time}"
-    format_separator = " \| "
+    format_separator = r" \| "
     format_time = "%I:%M %p"
     format_timer = (
-        "\?color=time ([\?if=days {days}d ][\?if=hours {hours}h ]"
-        "[\?if=minutes {minutes}m])[\?if=is_current  left]"
+        r"\?color=time ([\?if=days {days}d ][\?if=hours {hours}h ]"
+        r"[\?if=minutes {minutes}m])[\?if=is_current  left]"
     )
     ignore_all_day_events = False
     num_events = 3
+    preferred_event_link = "htmlLink"
     response = ["accepted"]
     thresholds = []
     time_to_max = 180
@@ -193,8 +212,8 @@ class Py3status:
         self.events = None
         self.no_update = False
 
-        self.client_secret = os.path.expanduser(self.client_secret)
-        self.auth_token = os.path.expanduser(self.auth_token)
+        self.client_secret = Path(self.client_secret).expanduser()
+        self.auth_token = Path(self.auth_token).expanduser()
 
         self.credentials = self._get_credentials()
         self.is_authorized = False
@@ -208,14 +227,11 @@ class Py3status:
 
         Returns: Credentials, the obtained credential.
         """
-        client_secret_path = os.path.dirname(self.client_secret)
-        auth_token_path = os.path.dirname(self.auth_token)
+        client_secret_path = self.client_secret.parent
+        auth_token_path = self.auth_token.parent
 
-        if not os.path.exists(auth_token_path):
-            os.makedirs(auth_token_path)
-
-        if not os.path.exists(client_secret_path):
-            os.makedirs(client_secret_path)
+        auth_token_path.mkdir(parents=True, exist_ok=True)
+        client_secret_path.mkdir(parents=True, exist_ok=True)
 
         flags = tools.argparser.parse_args(args=[])
         store = Storage(self.auth_token)
@@ -235,7 +251,7 @@ class Py3status:
             Have to restart i3 after getting credentials to prevent bad output.
             This only has to be done once on the first run of the module.
             """
-            self.py3.command_run("{} restart".format(self.py3.get_wm_msg()))
+            self.py3.command_run(f"{self.py3.get_wm_msg()} restart")
 
         return credentials
 
@@ -259,7 +275,7 @@ class Py3status:
 
         Returns: The list of events.
         """
-        self.last_update = datetime.datetime.now()
+        self.last_update = time.monotonic()
         time_min = datetime.datetime.utcnow()
         time_max = time_min + datetime.timedelta(hours=self.events_within_hours)
         events = []
@@ -306,8 +322,8 @@ class Py3status:
 
                 # filter out blacklisted event names
                 if event["summary"] is not None:
-                    if event["summary"].lower() in map(
-                        lambda e: e.lower(), self.blacklist_events
+                    if event["summary"].lower() in (
+                        e.lower() for e in self.blacklist_events
                     ):
                         continue
 
@@ -325,15 +341,15 @@ class Py3status:
             self.py3.notify_user(warn_message, "warning", self.warn_timeout)
 
     def _gstr_to_date(self, date_str):
-        """ Returns a dateime object from calendar date string."""
+        """Returns a dateime object from calendar date string."""
         return parser.parse(date_str).replace(tzinfo=tzlocal())
 
     def _gstr_to_datetime(self, date_time_str):
-        """ Returns a datetime object from calendar date/time string."""
+        """Returns a datetime object from calendar date/time string."""
         return parser.parse(date_time_str)
 
     def _datetime_to_str(self, date_time, dt_format):
-        """ Returns a strftime formatted string from a datetime object."""
+        """Returns a strftime formatted string from a datetime object."""
         return date_time.strftime(dt_format)
 
     def _delta_time(self, date_time):
@@ -397,7 +413,9 @@ class Py3status:
             event_dict["summary"] = event.get("summary")
             event_dict["location"] = event.get("location")
             event_dict["description"] = event.get("description")
-            self.event_urls.append(event["htmlLink"])
+            self.event_urls.append(
+                event.get(self.preferred_event_link, event.get("htmlLink"))
+            )
 
             if event["start"].get("date") is not None:
                 start_dt = self._gstr_to_date(event["start"].get("date"))
@@ -500,16 +518,15 @@ class Py3status:
             if button_index == "sep":
                 self.py3.prevent_refresh()
             elif button == self.button_refresh:
-                now = datetime.datetime.now()
-                diff = (now - self.last_update).seconds
-                if diff > 1:
+                # wait before the next refresh
+                if time.monotonic() - self.last_update > 1:
                     self.no_update = False
             elif button == self.button_toggle:
                 self.button_states[button_index] = not self.button_states[button_index]
             elif button == self.button_open:
                 if self.event_urls:
                     self.py3.command_run(
-                        "xdg-open {}".format(self.event_urls[button_index])
+                        self.browser_invocation.format(self.event_urls[button_index])
                     )
                 self.py3.prevent_refresh()
             else:
