@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Support i3pystatus modules in py3status.
 
@@ -47,9 +46,8 @@ SAMPLE OUTPUT
 {'full_text': 'i3pystatus module'}
 """
 
-import os
-
 from importlib import import_module
+from pathlib import Path
 from threading import Timer
 
 try:
@@ -94,21 +92,16 @@ def get_backends():
     global backends
     if backends is None:
         backends = {}
-        i3pystatus_dir = os.path.dirname(i3pystatus.__file__)
-        subdirs = [
-            x
-            for x in next(os.walk(i3pystatus_dir))[1]
-            if not x.startswith("_") and x not in IGNORE_DIRS
-        ]
-        for subdir in subdirs:
-            dirs = next(os.walk(os.path.join(i3pystatus_dir, subdir)))[2]
-            backends.update(
-                {
-                    x[:-3]: "i3pystatus.%s.%s" % (subdir, x[:-3])
-                    for x in dirs
-                    if not x.startswith("_") and x.endswith(".py")
-                }
-            )
+        i3pystatus_dir = Path(i3pystatus.__file__).parent
+        for subdir in i3pystatus_dir.iterdir():
+            if (
+                subdir.is_dir()
+                and not subdir.name.startswith("_")
+                and subdir.name not in IGNORE_DIRS
+            ):
+                for path in subdir.glob("*.py"):
+                    if not path.stem.startswith("_"):
+                        backends[path.stem] = f"i3pystatus.{subdir.name}.{path.stem}"
     return backends
 
 
@@ -226,16 +219,13 @@ SKIP_ATTRS = [
 
 
 class Py3status:
-    """
-    """
+    """"""
 
     # available configuration parameters
     module = None
 
     def post_config_hook(self):
-        if self.py3.is_python_2():
-            raise Exception(STRING_NOT_SUPPORTED)
-        elif not i3pystatus:
+        if not i3pystatus:
             raise Exception(STRING_NOT_INSTALLED)
         elif not self.module:
             raise Exception(STRING_MISSING_MODULE)
@@ -306,9 +296,9 @@ class Py3status:
 
         # get callbacks available, useful for deciding if double clicks exist
         callbacks = []
-        for i in range(len(CLICK_EVENTS)):
-            click = getattr(module, CLICK_EVENTS[i], None)
-            dbclick = getattr(module, DBL_CLICK_EVENTS[i], None)
+        for click_event, dbl_click_event in zip(CLICK_EVENTS, DBL_CLICK_EVENTS):
+            click = getattr(module, click_event, None)
+            dbclick = getattr(module, dbl_click_event, None)
             callbacks.append((click, dbclick))
 
         self._click_timer = ClickTimer(self, callbacks)
