@@ -76,14 +76,15 @@ INTERFACE_BATTERY = INTERFACE + ".battery"
 INTERFACE_NOTIFICATIONS = INTERFACE + ".notifications"
 PATH = "/modules/kdeconnect"
 DEVICE_PATH = PATH + "/devices"
+BATTERY_SUBPATH = "/battery"
+NOTIFICATIONS_SUBPATH = "/notifications"
 UNKNOWN = "Unknown"
 UNKNOWN_DEVICE = "unknown device"
 UNKNOWN_SYMBOL = "?"
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     cache_timeout = 30
@@ -99,7 +100,9 @@ class Py3status:
     status_notif = " ✉"
 
     def post_config_hook(self):
+        self._bat = None
         self._dev = None
+        self._not = None
 
     def _init_dbus(self):
         """
@@ -113,7 +116,19 @@ class Py3status:
                 return False
 
         try:
-            self._dev = _bus.get(SERVICE_BUS, DEVICE_PATH + "/%s" % self.device_id)
+            self._dev = _bus.get(SERVICE_BUS, DEVICE_PATH + f"/{self.device_id}")
+            try:
+                self._bat = _bus.get(
+                    SERVICE_BUS, DEVICE_PATH + f"/{self.device_id}" + BATTERY_SUBPATH
+                )
+                self._not = _bus.get(
+                    SERVICE_BUS,
+                    DEVICE_PATH + f"/{self.device_id}" + NOTIFICATIONS_SUBPATH,
+                )
+            except Exception:
+                # Fallback to the old version
+                self._bat = None
+                self._not = None
         except Exception:
             return False
 
@@ -130,7 +145,7 @@ class Py3status:
             return devices[0]
 
         for id in devices:
-            self._dev = bus.get(SERVICE_BUS, DEVICE_PATH + "/%s" % id)
+            self._dev = bus.get(SERVICE_BUS, DEVICE_PATH + f"/{id}")
             if self.device == self._dev.name:
                 return id
 
@@ -170,9 +185,15 @@ class Py3status:
         Get the battery
         """
         try:
+            if self._bat:
+                charge = self._bat.charge
+                isCharging = self._bat.isCharging
+            else:
+                charge = self._dev.charge()
+                isCharging = self._dev.isCharging()
             battery = {
-                "charge": self._dev.charge(),
-                "isCharging": self._dev.isCharging() == 1,
+                "charge": charge,
+                "isCharging": isCharging == 1,
             }
         except Exception:
             return None
@@ -184,7 +205,11 @@ class Py3status:
         Get notifications
         """
         try:
-            notifications = {"activeNotifications": self._dev.activeNotifications()}
+            if self._not:
+                notifications = {"activeNotifications": self._not.activeNotifications()}
+            else:
+                notifications = {"activeNotifications": self._dev.activeNotifications()}
+            notifications = {"activeNotifications": notifications}
         except Exception:
             return None
 
@@ -194,7 +219,7 @@ class Py3status:
         """
         Get the battery status
         """
-        if battery["charge"] == -1:
+        if not battery or battery["charge"] == -1:
             return (UNKNOWN_SYMBOL, UNKNOWN, "#FFFFFF")
 
         if battery["isCharging"]:
