@@ -4,7 +4,7 @@ Display song currently playing in mpd.
 Configuration parameters:
     cache_timeout: how often we refresh this module in seconds (default 2)
     format: template string (see below)
-        (default '{state} [[[{artist}] - {title}]|[{file}]]')
+        (default '{state} [[[{artist} ]- {title}]|[{file}]]')
     hide_on_error: hide the status if an error has occurred (default False)
     hide_when_paused: hide the status if state is paused (default False)
     hide_when_stopped: hide the status if state is stopped (default True)
@@ -83,7 +83,7 @@ def song_attr(song, attr):
             duration = int(song["time"])
             if duration > 0:
                 minutes, seconds = divmod(duration, 60)
-                return "{:d}:{:02d}".format(minutes, seconds)
+                return f"{minutes:d}:{seconds:02d}"
             raise ValueError
         except (KeyError, ValueError):
             return ""
@@ -101,12 +101,11 @@ def song_attr(song, attr):
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     cache_timeout = 2
-    format = "{state} [[[{artist}] - {title}]|[{file}]]"
+    format = "{state} [[[{artist} ]- {title}]|[{file}]]"
     hide_on_error = False
     hide_when_paused = False
     hide_when_stopped = True
