@@ -31,8 +31,7 @@ from urllib.request import urlopen, URLError
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     cache_timeout = 10
@@ -61,7 +60,7 @@ class Py3status:
     def post_config_hook(self):
         self.color_on = self.py3.COLOR_ON or self.py3.COLOR_GOOD
         self.color_off = self.py3.COLOR_OFF or self.py3.COLOR_BAD
-        self.ping_command = ["ping", "-c", "1", "-W", "%s" % self.timeout, self.url]
+        self.ping_command = ["ping", "-c", "1", "-W", f"{self.timeout}", self.url]
 
     def _connection_present(self):
         if "://" in self.url:
