@@ -71,8 +71,7 @@ SPOTIFY_CMD = """dbus-send --print-reply --dest={dbus_client}
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     button_next = None
@@ -101,8 +100,7 @@ class Py3status:
         return SPOTIFY_CMD.format(dbus_client=self.dbus_client, cmd=action)
 
     def post_config_hook(self):
-        """
-        """
+        """ """
         # Match string after hyphen, comma, semicolon or slash containing any metadata word
         # examples:
         # - Remastered 2012
@@ -129,6 +127,12 @@ class Py3status:
         expression = expression.replace("META_WORDS_HERE", meta_words)
         return re.compile(expression, re.IGNORECASE)
 
+    def _get_playback_status(self):
+        """
+        Get the playback status. One of: "Playing", "Paused" or "Stopped".
+        """
+        return self.player.Get("org.mpris.MediaPlayer2.Player", "PlaybackStatus")
+
     def _get_text(self):
         """
         Get the current song metadatas (artist - title)
@@ -143,15 +147,13 @@ class Py3status:
                 album = metadata.get("xesam:album")
                 artist = metadata.get("xesam:artist")[0]
                 microtime = metadata.get("mpris:length")
-                rtime = str(timedelta(microseconds=microtime))[:-7]
+                rtime = str(timedelta(seconds=microtime // 1_000_000))
                 title = metadata.get("xesam:title")
                 if self.sanitize_titles:
                     album = self._sanitize_title(album)
                     title = self._sanitize_title(title)
 
-                playback_status = self.player.Get(
-                    "org.mpris.MediaPlayer2.Player", "PlaybackStatus"
-                )
+                playback_status = self._get_playback_status()
                 if playback_status == "Playing":
                     color = self.py3.COLOR_PLAYING or self.py3.COLOR_GOOD
                 else:
@@ -199,11 +201,16 @@ class Py3status:
         return response
 
     def on_click(self, event):
-        """
-        """
+        """ """
         button = event["button"]
         if button == self.button_play_pause:
-            self.py3.command_run(self._spotify_cmd("PlayPause"))
+            # we do not use the 'PlayPause' command because of a bug
+            # in spotifyd: https://github.com/Spotifyd/spotifyd/issues/890
+            playback_status = self._get_playback_status()
+            if playback_status == "Playing":
+                self.py3.command_run(self._spotify_cmd("Pause"))
+            else:
+                self.py3.command_run(self._spotify_cmd("Play"))
             sleep(0.1)
         elif button == self.button_next:
             self.py3.command_run(self._spotify_cmd("Next"))
