@@ -26,6 +26,8 @@ import os
 import socket
 import threading
 
+from pathlib import Path
+
 
 class YubiKeyTouchDetectorListener(threading.Thread):
     """
@@ -74,15 +76,14 @@ class YubiKeyTouchDetectorListener(threading.Thread):
 
 
 class Py3status:
-    """
-    """
+    """ """
 
     # available configuration parameters
     format = r"[YubiKey[\?if=is_gpg ][\?if=is_u2f ]]"
     socket_path = "$XDG_RUNTIME_DIR/yubikey-touch-detector.socket"
 
     def post_config_hook(self):
-        self.socket_path = os.path.expanduser(self.socket_path)
+        self.socket_path = Path(self.socket_path).expanduser()
         self.socket_path = os.path.expandvars(self.socket_path)
 
         self.status = {"is_gpg": False, "is_u2f": False}
