@@ -1,9 +1,9 @@
-import codecs
 import os
 import re
 
 from collections import OrderedDict
 from importlib import util
+from pathlib import Path
 from string import Template
 from subprocess import check_output, CalledProcessError
 
@@ -38,7 +38,7 @@ class ParseException(Exception):
         self.token = token.replace("\n", "\\n")
 
     def one_line(self, config_path):
-        filename = os.path.basename(config_path)
+        filename = config_path.name
         notif = "CONFIG ERROR: {} saw `{}` at line {} position {} in file {}"
         return notif.format(
             self.error, self.token, self.line_no, self.position, filename
@@ -183,8 +183,8 @@ class ConfigParser:
         name = name.split()[0]
         if name in self.container_modules:
             return
-        root = os.path.dirname(os.path.realpath(__file__))
-        module_path = os.path.join(root, "modules")
+        root = Path(__file__).resolve().parent
+        module_path = root / "modules"
         info = util.find_spec(name, [module_path])
         if not info:
             return
@@ -198,7 +198,7 @@ class ConfigParser:
         if container:
             self.container_modules.append(name)
         else:
-            self.error("Module `{}` cannot contain others".format(name))
+            self.error(f"Module `{name}` cannot contain others")
 
     def check_module_name(self, name, offset=0):
         """
@@ -303,7 +303,7 @@ class ConfigParser:
                 return r"\\"
             return match.group(0).encode("utf-8").decode("unicode-escape")
 
-        return re.sub(r"\\\\|\\u\w{4}|\\U\w{8}|\\N\{([^}\\]|\\.)+\}", fix_fn, value)
+        return re.sub(r"\\\\|\\u\w{4}|\\U\w{8}|\\N{([^}\\]|\\.)+}", fix_fn, value)
 
     def make_value(self, value):
         """
@@ -378,7 +378,7 @@ class ConfigParser:
         """
         value = os.getenv(param)
         if value is None:
-            self.notify_user("Environment variable `%s` undefined" % param)
+            self.notify_user(f"Environment variable `{param}` undefined" % param)
         return self.value_convert(value, value_type)
 
     def make_value_from_shell(self, param, value_type, function):
@@ -394,7 +394,7 @@ class ConfigParser:
             else:
                 if self.py3_wrapper:
                     self.py3_wrapper.report_exception(
-                        msg="shell: called with command `%s`" % param
+                        msg=f"shell: called with command `{param}`"
                     )
                 self.notify_user("shell script exited with an error")
                 value = None
@@ -425,18 +425,17 @@ class ConfigParser:
 
                 value = base64.b64decode(value).decode("utf-8")
             except TypeError as e:
-                self.notify_user("base64(..) error %s" % str(e))
+                self.notify_user(f"base64(..) error {e}")
 
         # check we are in a module definition etc
         if not self.current_module:
-            self.notify_user("%s(..) used outside of module or section" % function)
+            self.notify_user(f"{function}(..) used outside of module or section")
             return None
 
         module = self.current_module[-1].split()[0]
         if module in CONFIG_FILE_SPECIAL_SECTIONS + I3S_MODULE_NAMES:
             self.notify_user(
-                "%s(..) cannot be used outside of py3status module "
-                "configuration" % function
+                f"{function}(..) cannot be used outside of py3status module configuration"
             )
             return None
 
@@ -531,7 +530,7 @@ class ConfigParser:
             elif t_value == "(":
                 return tuple(self.make_list(end_token=")"))
             else:
-                self.error("Value expected", previous=not (end_token))
+                self.error("Value expected", previous=not end_token)
 
     def module_def(self):
         """
@@ -581,7 +580,7 @@ class ConfigParser:
             elif scheme == "hide":
                 value = PrivateHide(value, module_name)
             else:
-                self.error("Unknown scheme {} for data".format(scheme))
+                self.error(f"Unknown scheme {scheme} for data")
 
         return name, value
 
@@ -623,7 +622,7 @@ class ConfigParser:
                     if name.split(":")[0] not in dictionary:
                         # order is treated specially
                         if not (self.level == 1 and name == "order"):
-                            self.error("{} does not exist".format(name))
+                            self.error(f"{name} does not exist")
                 if t_value in ["{"]:
                     if self.current_module:
                         self.check_child_friendly(self.current_module[-1])
@@ -647,7 +646,7 @@ class ConfigParser:
                         and " " not in name
                         and name not in I3S_MODULE_NAMES
                     ):
-                        name = "{} _anon_module_{}".format(name, self.anon_count)
+                        name = f"{name} _anon_module_{self.anon_count}"
                         self.anon_count += 1
                     dictionary[name] = value
                 # assignment of value
@@ -717,13 +716,13 @@ def process_config(config_path, py3_wrapper=None):
         # bsd does not have the --mime-encoding so assume utf-8
         encoding = "utf-8"
     try:
-        with codecs.open(config_path, "r", encoding) as f:
+        with config_path.open("r", encoding=encoding) as f:
             try:
                 config_info = parse_config(f)
             except ParseException as e:
                 config_info = parse_config_error(e, config_path)
     except LookupError:
-        with codecs.open(config_path) as f:
+        with config_path.open() as f:
             try:
                 config_info = parse_config(f)
             except ParseException as e:
@@ -844,10 +843,8 @@ def process_config(config_path, py3_wrapper=None):
             continue
         module_name = name.split(" ")[0]
         if module_name in RETIRED_MODULES:
-            old = "`{}`".format(module_name)
-            new = ", ".join(
-                "`{}`".format(x) for x in RETIRED_MODULES[module_name]["new"]
-            )
+            old = f"`{module_name}`"
+            new = ", ".join(f"`{x}`" for x in RETIRED_MODULES[module_name]["new"])
             msg = RETIRED_MODULES[module_name]["msg"].format(old=old, new=new)
             notify_user(msg)
             continue
@@ -888,6 +885,6 @@ if __name__ == "__main__":
     if len(sys.argv) > 1:
         file_name = sys.argv[1]
     else:
-        file_name = os.path.join(os.path.expanduser("~"), ".i3/i3status.conf")
-    print("\nPARSING CONFIG FILE %s\n\n" % file_name)
+        file_name = Path.home() / ".i3/i3status.conf"
+    print(f"\nPARSING CONFIG FILE {file_name}\n\n")
     pprint.pprint(process_config(file_name))
