@@ -1,14 +1,16 @@
 import os
 import sys
 import shlex
+import time
 
 from collections.abc import Mapping
 from copy import deepcopy
 from fnmatch import fnmatch
 from math import log10
+from pathlib import Path
 from pprint import pformat
+from shutil import which
 from subprocess import Popen, PIPE, STDOUT
-from time import time
 from uuid import uuid4
 
 from py3status import exceptions
@@ -124,7 +126,7 @@ class Py3:
         if it exists
         """
         if not name.startswith("COLOR_"):
-            raise AttributeError("Attribute `%s` not in Py3" % name)
+            raise AttributeError(f"Attribute `{name}` not in Py3")
         return self._get_config_setting(name.lower())
 
     def _get_config_setting(self, name, default=None):
@@ -295,7 +297,7 @@ class Py3:
             d = dict(enumerate(d))
         for k, v in d.items():
             if parent_key:
-                k = "{}{}{}".format(parent_key, delimiter, k)
+                k = f"{parent_key}{delimiter}{k}"
             if intermediates:
                 items.append((k, v))
             if isinstance(v, list):
@@ -459,7 +461,7 @@ class Py3:
                 message = "\n" + message
         except:  # noqa e722
             pass
-        message = "Module `{}`: {}".format(self._module.module_full_name, message)
+        message = f"Module `{self._module.module_full_name}`: {message}"
         self._py3_wrapper.log(message, level)
 
     def update(self, module_name=None):
@@ -522,7 +524,7 @@ class Py3:
         if isinstance(msg, Composite):
             msg = msg.text()
         if title is None:
-            title = "py3status: {}".format(module_name)
+            title = f"py3status: {module_name}"
         elif isinstance(title, Composite):
             title = title.text()
         if msg:
@@ -623,11 +625,12 @@ class Py3:
                 if seconds:
                     seconds -= 0.1
 
-        requested = time() + seconds - offset
+        current_time = time.time()
+        requested = time.monotonic() + seconds - offset
 
         # if sync_to then we find the sync time for the requested time
         if sync_to:
-            requested = (requested + sync_to) - (requested % sync_to)
+            requested = (requested + sync_to) - (current_time % sync_to)
 
         return requested + offset
 
@@ -775,7 +778,12 @@ class Py3:
         return self._formatter.update_placeholder_formats(format_string, formats)
 
     def safe_format(
-        self, format_string, param_dict=None, force_composite=False, attr_getter=None
+        self,
+        format_string,
+        param_dict=None,
+        force_composite=False,
+        attr_getter=None,
+        max_width=None,
     ):
         r"""
         Parser for advanced formatting.
@@ -832,18 +840,33 @@ class Py3:
 
         attr_getter is a function that will when called with an attribute name
         as a parameter will return a value.
+
+        max_width lets you to control the total max width of 'full_text' the
+        module is allowed to output on the bar.
         """
         try:
-            return self._formatter.format(
+            result = self._formatter.format(
                 format_string,
                 self._py3status_module,
                 param_dict,
                 force_composite=force_composite,
                 attr_getter=attr_getter,
             )
-        except Exception:
-            self._report_exception("Invalid format `{}`".format(format_string))
-            return "invalid format"
+            if max_width is not None and max_width > 0:
+                if isinstance(result, str):
+                    result = result[:max_width]
+                elif isinstance(result, Composite):
+                    chars_left = max_width
+                    for composite in result:
+                        if "index" in composite:
+                            continue
+                        composite["full_text"] = composite["full_text"][:chars_left]
+                        chars_left -= len(composite["full_text"])
+                        chars_left = max(0, chars_left)
+            return result
+        except Exception as err:
+            self._report_exception(f"Invalid format `{format_string}` ({err})")
+            return f"invalid format ({err})"
 
     def build_composite(
         self, format_string, param_dict=None, composites=None, attr_getter=None
@@ -878,7 +901,7 @@ class Py3:
                 attr_getter=attr_getter,
             )
         except Exception:
-            self._report_exception("Invalid format `{}`".format(format_string))
+            self._report_exception(f"Invalid format `{format_string}`")
             return [{"full_text": "invalid format"}]
 
     def composite_update(self, item, update_dict, soft=False):
@@ -925,7 +948,7 @@ class Py3:
 
     def check_commands(self, cmd_list):
         """
-        Checks to see if commands in list are available using ``which``.
+        Checks to see if commands in list are available using shutil.which().
 
         returns the first available command.
 
@@ -937,7 +960,7 @@ class Py3:
             cmd_list = [cmd_list]
 
         for cmd in cmd_list:
-            if self.command_run("which {}".format(cmd)) == 0:
+            if which(cmd) is not None:
                 return cmd
 
     def command_run(self, command):
@@ -958,7 +981,7 @@ class Py3:
                 pretty_cmd = command
             else:
                 pretty_cmd = " ".join(command)
-            msg = "Command `{cmd}` {error}".format(cmd=pretty_cmd, error=e.errno)
+            msg = f"Command `{pretty_cmd}` {e.errno}"
             raise exceptions.CommandError(msg, error_code=e.errno)
 
     def command_output(
@@ -998,7 +1021,7 @@ class Py3:
                 env=env,
             )
         except Exception as e:
-            msg = "Command `{cmd}` {error}".format(cmd=pretty_cmd, error=e)
+            msg = f"Command `{pretty_cmd}` {e}"
             self.log(msg)
             raise exceptions.CommandError(msg, error_code=e.errno)
 
@@ -1103,8 +1126,8 @@ class Py3:
             if cmd:
                 if cmd == "ffplay":
                     cmd = "ffplay -autoexit -nodisp -loglevel 0"
-                sound_file = os.path.expanduser(sound_file)
-                c = shlex.split("{} {}".format(cmd, sound_file))
+                sound_file = Path(sound_file).expanduser()
+                c = shlex.split(f"{cmd} {sound_file}")
                 self._audio = Popen(c)
 
     def stop_sound(self):
@@ -1208,7 +1231,7 @@ class Py3:
 
         # save color so it can be accessed via safe_format()
         if name:
-            color_name = "color_threshold_%s" % name
+            color_name = f"color_threshold_{name}"
         else:
             color_name = "color_threshold"
         setattr(self._py3status_module, color_name, color)
@@ -1270,7 +1293,7 @@ class Py3:
             retry_wait = getattr(self._py3status_module, "request_retry_wait", 2)
 
         if "User-Agent" not in headers:
-            headers["User-Agent"] = "py3status/{} {}".format(version, self._uid)
+            headers["User-Agent"] = f"py3status/{version} {self._uid}"
 
         def get_http_response():
             return HttpResponse(
@@ -1291,8 +1314,8 @@ class Py3:
                     from gevent import sleep
                 else:
                     from time import sleep
-                self.log("HTTP request retry {}/{}".format(n, retry_times))
+                self.log(f"HTTP request retry {n}/{retry_times}")
                 sleep(retry_wait)
-        self.log("HTTP request retry {}/{}".format(retry_times, retry_times))
+        self.log(f"HTTP request retry {retry_times}/{retry_times}")
         sleep(retry_wait)
         return get_http_response()
